@@ -56,9 +56,13 @@ statusLineImage w st =
       , nometaImage (view clientFocus st) st
       , scrollImage st
       , filterImage st
-      , latencyImage st
+      , latency
       ]
 
+    latency
+      | view clientShowPing st = latencyImage st
+      | otherwise              = mempty
+
     activity
       | view clientActivityBar st = activityBarImages st
       | otherwise                 = [activitySummary st]
@@ -338,6 +342,7 @@ viewSubfocusLabel pal subfocus =
     FocusKeyMap   -> Just $ string (view palLabel pal) "keymap"
     FocusHelp mb  -> Just $ string (view palLabel pal) "help" <>
                             opt mb
+    FocusIgnoreList -> Just $ string (view palLabel pal) "ignores"
     FocusRtsStats -> Just $ string (view palLabel pal) "rtsstats"
     FocusMasks m  -> Just $ mconcat
       [ string (view palLabel pal) "masks"
