@@ -30,9 +30,11 @@ module Client.State
   , clientScroll
   , clientDetailView
   , clientActivityBar
+  , clientShowPing
   , clientSubfocus
   , clientNetworkMap
   , clientIgnores
+  , clientIgnoreMask
   , clientConnection
   , clientBell
   , clientExtensions
@@ -111,6 +113,7 @@ import           Client.Configuration.ServerSettings
 import           Client.Image.Message
 import           Client.Image.Palette
 import           Client.Log
+import           Client.Mask
 import           Client.Message
 import           Client.Network.Async
 import           Client.State.Channel
@@ -176,12 +179,14 @@ data ClientState = ClientState
   , _clientScroll            :: !Int                      -- ^ buffer scroll lines
   , _clientDetailView        :: !Bool                     -- ^ use detailed rendering mode
   , _clientActivityBar       :: !Bool                     -- ^ visible activity bar
+  , _clientShowPing          :: !Bool                     -- ^ visible ping time
   , _clientRegex             :: Maybe Regex               -- ^ optional persistent filter
   , _clientLayout            :: !LayoutMode               -- ^ layout mode for split screen
 
   , _clientBell              :: !Bool                     -- ^ sound a bell next draw
 
-  , _clientIgnores           :: !(HashSet Identifier)     -- ^ ignored nicknames
+  , _clientIgnores           :: !(HashSet Identifier)     -- ^ ignored masks
+  , _clientIgnoreMask        :: Mask                      -- ^ precomputed ignore regular expression (lazy)
 
   , _clientExtensions        :: !ExtensionState           -- ^ state of loaded extensions
   , _clientLogQueue          :: ![LogLine]                -- ^ log lines ready to write
@@ -240,11 +245,13 @@ withClientState cfgPath cfg k =
 
   withExtensionState $ \exts ->
 
-  do events         <- atomically newTQueue
+  do events <- atomically newTQueue
+     let ignoreIds = map mkId (view configIgnores cfg)
      k ClientState
         { _clientWindows           = _Empty # ()
         , _clientNetworkMap        = _Empty # ()
-        , _clientIgnores           = view configIgnores cfg
+        , _clientIgnores           = HashSet.fromList ignoreIds
+        , _clientIgnoreMask        = buildMask ignoreIds
         , _clientConnections       = _Empty # ()
         , _clientTextBox           = Edit.defaultEditBox
         , _clientTextBoxOffset     = 0
@@ -263,6 +270,7 @@ withClientState cfgPath cfg k =
         , _clientRegex             = Nothing
         , _clientLayout            = view configLayout cfg
         , _clientActivityBar       = view configActivityBar cfg
+        , _clientShowPing          = view configShowPing cfg
         , _clientBell              = False
         , _clientExtensions        = exts
         , _clientLogQueue          = []
@@ -404,17 +412,17 @@ ircIgnorable msg !st =
     _                    -> Nothing
   where
     checkUser !who
-      | identIgnored (userNick who) st = Just (userNick who)
-      | otherwise                      = Nothing
+      | identIgnored who st = Just (userNick who)
+      | otherwise           = Nothing
 
 
 
 -- | Predicate for nicknames to determine if messages should be ignored.
 identIgnored ::
-  Identifier  {- ^ nickname     -} ->
+  UserInfo    {- ^ target user  -} ->
   ClientState {- ^ client state -} ->
   Bool        {- ^ is ignored   -}
-identIgnored who st = HashSet.member who (view clientIgnores st)
+identIgnored who st = matchMask (view clientIgnoreMask st) who
 
 
 -- | Record a message in the windows corresponding to the given target
